#
# spec file for package libxfce4util
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with git
%define libname libxfce4util7
Name:           libxfce4util
Version:        4.20.0
Release:        1.1
Summary:        Utility Library for the Xfce Desktop Environment
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://www.xfce.org/
Source0:        https://archive.xfce.org/src/xfce/libxfce4util/4.20/%{name}-%{version}.tar.bz2
Source100:      %{name}-rpmlintrc
BuildRequires:  gettext >= 0.19.8
BuildRequires:  perl
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.72.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.72.0
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 1.72.0
BuildRequires:  pkgconfig(gtk-doc) >= 1.20
BuildRequires:  pkgconfig(vapigen)
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif

%description
libxfce4util is a general-purpose utility library with core application support
for the Xfce Desktop Environment.

%package tools
Summary:        Tools for libxfce4util
Group:          System/Libraries
Provides:       libxfce4util:%{_sbindir}/xfce4-kiosk-query

%description tools
This package contains tools for libxfce4util.

%package -n %{libname}
Summary:        Utility Library for the Xfce Desktop Environment
Group:          System/Libraries
Recommends:     %{name}-lang = %{version}
Provides:       libxfce4util = %{version}
Obsoletes:      libxfce4util <= 4.8.2

%description -n %{libname}
libxfce4util is a general-purpose utility library with core application support
for the Xfce Desktop Environment.

%package -n typelib-1_0-Libxfce4util-1_0
Summary:        Utility Library for the Xfce Desktop Environment
Group:          System/Libraries
Provides:       typelib-1_0-libxfce4util-1_0 = %{version}
Obsoletes:      typelib-1_0-libxfce4util-1_0 < %{version}

%description -n typelib-1_0-Libxfce4util-1_0
libxfce4util is a general-purpose utility library with core application support
for the Xfce Desktop Environment.

%package devel
Summary:        Development Files for libxfce4util
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       %{name}-tools = %{version}
Requires:       typelib-1_0-Libxfce4util-1_0 = %{version}

%description devel
This package contains the API documentation and development files needed for
developing applications based on libxfce4util.

%lang_package

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode \
    --enable-vala=yes \
    --disable-static \
    --enable-gtk-doc
%else
%configure \
    --enable-vala=yes \
    --disable-static
%endif

%make_build

%install
%make_install

find %{buildroot} -type f -name "*.la" -delete -print

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,ur_PK,tl_PH}

%find_lang %{name} %{?no_lang_C}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files tools
%{_sbindir}/xfce4-kiosk-query

%files lang -f %{name}.lang

%files -n %{libname}
%doc AUTHORS NEWS README.md
%license COPYING
%{_libdir}/libxfce4util.so.*

%files -n typelib-1_0-Libxfce4util-1_0
%{_libdir}/girepository-1.0/Libxfce4util-1.0.typelib

%files devel
%{_libdir}/pkgconfig/libxfce4util-*.pc
%{_libdir}/libxfce4util.so
%dir %{_includedir}/xfce4
%{_includedir}/xfce4/libxfce4util/
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/libxfce4util
%{_datadir}/gir-1.0/Libxfce4util-1.0.gir
%{_datadir}/vala/vapi/

%changelog
* Sun Dec 15 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.20.0
  * Translation Updates
* Sun Dec  1 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.5 [development release]
  * Bump Xfce overall version to 4.20pre2
  * I18n: Update po/LINGUAS list
  * Call xfce_kiosk's parent finalizer to prevent leaks
  * Translation Updates
* Sat Nov  2 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.19.4 [development release]
  * bump Xfce overall version to 4.20pre1
  * Remove local ABI check
  * Add meson build
  * Migrate to xdt-gen-visibility and xdt-check-abi
  * I18n: Update po/LINGUAS list
  * build: Bump requirements for Xfce 4.20
  * Apply .clang-format file
  * Add missing includes of libxfce4util-alias.h
  * clang-format: Add file
  * xfce-rc: Fix support for the LANGUAGE environment variable
  * scan-build: Add false positive file
  * build: Use AM_DISTCHECK_CONFIGURE_FLAGS
  * session-management: Try to create D-BUS proxy synchronously
  * session-management: Always set an error when returning FALSE
  * fileutils: Fix MD5 hash in xfce_create_shared_thumbnail_path()
  * Translation Updates
- Add BuildRequire: pkgconfig(gtk-doc)
* Tue Apr  2 2024 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.19.3
* Mon Feb  5 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.2
  * Update copyright year
  * Search for bind_textdomain_codeset in libintl too
  * xfce-rc: Add support for the LANGUAGE environment variable
  * Add missing config.h includes
  * Improve checksum calculation (#17)
  * xfce-rc: Document the fact that delimiter escaping is not
    supported
  * xfce-rc: Properly write translated entries when available
  * Update bug report address
* Wed Jan 11 2023 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.18.1
  * Handle remaining escape sequences
  * Fix desktop entry value escaping
- Remove unused _service file
* Sun Dec 18 2022 Dirk Müller <dmueller@suse.com>
- update to 4.18.0:
  * Bump requirements for Xfce 4.18
  * Bump copyright to 2022
  * Bump GObject Introspection minim version to 1.66
  * Clean the build system and use the new XDT_VERSION_INIT
  * Create new function xfce_create_shared_thumbnail_path
  * doc: Fix typo in `xfce_*_append_quoted()`
  * docs: Add missing index of deprecated symbols
  * docs: Fix "unused declarations" warning
  * docs: Fix broken links
  * docs: Fix return value of xfce_str_replace
  * docs: Update `.gitignore`
  * Fix (some) GObject introspection warnings
  * Fix document generation error
  * Fix documentation of 'xfce_str_is_empty'
  * Fix some GObject introspection warnings
  * i18n: Make sure to set locale according to environment
  * libxfce4util needs to be first character Capital
  * Move xfce_append_quoted () to xfce-string
  * Partially revert "Fix (some) GObject introspection warnings"
  * Remove duplicate xfce_str_is_empty
  * Remove invalid custom ngettext() macro
  * Remove limit on the size of configuration file line
  * Revamp the documentation to uniformize accross components
  * Silence `-Wanalyzer-null-dereference` warnings
  * Translation Updates
  * Update COPYING
  * usage of g_file_peek_path requires glib 2.56
  * xfce-miscutils: Fix `deadcode.DeadStores` warning from `scan-build`
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  * Bump xfce_version_string to 4.16
  * Properly handle URI schemes other than "file"
* Sun Dec 13 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.6
  * Update configure.ac.in syntax
  * Namespace of the gir needs capital first letter
  * Bump GLib (and gio, gthread, etc) minimum to 2.50.0
  * Remove typedef already defined by G_DECLARE_FINAL_TYPE macro
    (gxo#xfce/libxfce4util#4)
- Rename typelib subpackage to match gir name
* Sat Nov 21 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.5
  * Bump Xfce version to 4.16pre2
  * Add README.md to EXTRA_DIST
* Tue Nov  3 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.4
  * Create README.md
  * Translation Updates
* Fri Aug 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.15.3
  * Complete the field codes expansion
  * Add field codes expansion and related utilities
    (code moved from garcon)
  * docs: Show the "Miscellaneous Utilities" section
  * Translation updates
* Wed Aug 21 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Split out typelib-1_0-libxfce4util-1_0 from -devel package: the
  .typelib files are not development files, but are actively used
  at runtime.
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Sun Aug 11 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.14.0
  * Bump to Xfce version 4.14
- Cleaned up spec file
* Sun Jul 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Enable vala (bxo#15756)
* Sun Jul 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 4.13.5
  * Translation updates
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.13.4
  * Bump the Xfce version to 4.14pre2
  * Translation Updates
* Thu May 16 2019 Vinzenz Vietzke <vinz@vinzv.de>
- Update to 4.13.3
  * Add support for rc files as symlinks (bxo#14698)
  * Fix GObject Introspection language bindings (bxo#14766)
  * Fix compiler error -Wcast-function-type (GCC 8)
  * Bump minimum glib version
  * Fix compilation warnings ""defined" may not be portable"
  * Translation Updates: Arabic, Belarusian, Czech, Danish, French,
    Galician, Hebrew, Icelandic, Italian, Kazakh, Lithuanian, Malay,
    Norwegian Bokmål, Occitan (post 1500),
    Romanian, Slovak, Serbian, Uighur, Ukrainian
- Updated Url and Source Url
- Switched from -lang to %%lang_package
* Sat Apr 27 2019 maurizio.galli@gmail.com
- Update to 4.13.2
  * Add VAPIGEN for vala binding generation.
  * Fix make distcheck build
  * Better documentation processing (migrate away from sgml templates)
  * Allow language-specific keys before language-neutral ones
    (bxo#13979)
  * Translation updates
- Changes from 4.13.1
  * Fix a minor typo: ment → meant
  * Fix some autotools warnings, default debug to yes
  * Fix duplicate DISTCHECK_CONFIGURE_FLAGS
  * Improve gobject-introspection annotations
- Changes from 4.13.0
  * Fix abicheck to handle ppc64 architecture
  * Add support for GOBJECT-INTROSPECTION bxo#12159
  * Translation updates
- Clean up spec file and dropped obsolete macros
- Added conditional %%bcond_with git for easier maintanance when using
  git master branch
- Dropped obsolete libxfce4util-xfce-rc-i18n.patch
* Fri Sep 22 2017 seife+obs@b1-systems.com
- disable gtk-doc build, fails with newer gtk-doc > 1.25
- do not package ChangeLog, NEWS is enough
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.1
  - fix small mistake in 4.12.0, xfce_version_string was left at
    4.10
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - update libtool version to reflect dropped symbols (bxo#10737)
  - autotools updates
  - don't use freed rc file to avoid crash (bxo#9026)
  - remove unused or unrequired API functions: xfce_strjoin,
    xfce_gethostname, xfce_putenv, xfce_setenv, xfce_unsetenv
  - translation updates
* Wed Oct 15 2014 gber@opensuse.org
- add libxfce4util-xfce-rc-i18n.patch which translates Name,
  GenericName, and Comment entries of desktop files via gettext
  when read via the xfce_rc_* API, this is necessary since inline
  translations in openSUSE are removed in favor of gettext-based
  translations (bnc#829113)
* Wed Apr 30 2014 gber@opensuse.org
- update to version 4.10.0
  - autotools updates
  - don't use freed rc file to avoid crash (bxo#9026)
  - remove unused or unrequired API functions: xfce_strjoin,
    xfce_gethostname, xfce_putenv, xfce_setenv, xfce_unsetenv
  - translation updates
* Sun May  5 2013 gber@opensuse.org
- update to version 4.10.1
  - don't used freed rc file to avoid crash
  - autotools updates
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - translation updates
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.1
  - bump glib to 2.24
  - translation updates
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.0
  - make licenses static. You can only use
    xfce_get_license_text(...)
  - remove unused .h files
  - remove xfce_strip_context(), use g_strip_context()
  - remove XfceDesktopEntry
  - don't generate enum types
  - only link against glib
  - set version string to 4.10
  - remove spec file and rpm build
  - missing fallback for AC_RUN_IF_ELSE() when cross-compiling
  - fix XfceRc group parsing with brackets in name
  - reduce XfceRc structure size from from 216 to 176 bytes
  - use some macros and drop unneeded strlen's in XfceRc
  - use GSList in xfce-resource
  - bump verinfo to 6:0:0
  - translation updates
* Fri Mar 23 2012 gber@opensuse.org
- split into libxfce4util4, -tools, -lang subpackages conforming
  to the shared library policy
- correct build dependencies
* Mon Sep 19 2011 gber@opensuse.org
- update to version 4.8.2
  - remove the internal slice allocator macros
  - use chain to free slice instead of a loop
  - bugfixes
  - translation updates
- removed libxfce4util-4.8.1-fix-broken-assertion.patch which has
  been included upstream
* Sun Jan 30 2011 gber@opensuse.org
- improved descriptions/summary
- added libxfce4util-4.8.1-fix-broken-assertion.patch which fixes a
  broken assertion which causes xfce_strjoin to fail incorrectly
  (bxo#7122)
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.1
  - bugfixes
* Fri Dec 24 2010 gber@opensuse.org
- corrected license information
- corrected category
- improved summaries/descriptions
- show compiler output
* Wed Dec 15 2010 prusnak@opensuse.org
- remove tl_PH translation
* Sun Dec  5 2010 prusnak@opensuse.org
- update to 4.7.4
  - Fix wrong capitalization of Xfce.
  - Fix stdarg.h include (bug #6897).
  - Translation updates (pt).
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Mon Nov 22 2010 andrea@opensuse.org
- update to 4.7.3 (unstable release)
  * When a valid variable name is not found in the buffer, replace
  * it with nothing so the behavious is the same as the old implementation.
  * Allow multiple variable put together like $HOME$HOME$HOME.
  * Explicitly link to gobject for the gtkdocs.
  * Expand tilde in more situations in xfce_expand_variables().
  * Also allow to expand ~ and ~user in the following cases instead of
    only at the start of the command:
    ~ is after a space, a = sign or quoted (start with ' or "). This
  * allows to expand command line "thunar ~/music",
    "terminal --working-directory=~/scripts" or "thunar '~/my music'".
  * Also drop the static buffers and use a GString to build the function
    result.
  * Also fix a bug where underscores were no usable in expanding variables.
* Thu Jul 22 2010 andrea@opensuse.org
- new upstream version 4.6.2 (Xfce 4.6.2 release)
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 4.7.1
  - Remove po/LINGUAS file so it does not override the languages defined
    in the configure file.
- updated to 4.7.0
  - Build ChangeLog during make dist.
  - Silent the build.
  - Fix some compiler warnings.
  - Use new xdt macros, xfce-dev-tools 4.7.2 is required.
  - Various build changes for GIT.
  - Misc other small changes.
  - Translation updates (ca, zh_CN, es, da, gl, pa, ru, sq, lv, sk,
    kk, hu, ast, ur_PK, ur, tl_PH).
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 4.6.1
  * updated translations
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 4.6.0 (Xfce 4.6.0 release)
* Thu Feb 19 2009 crrodriguez@suse.de
- remove static libraries and "la" files
* Wed Nov  5 2008 bwalle@suse.de
- updated to 4.4.3
  * translations polish
  * bug fixes
* Mon Dec  3 2007 bwalle@suse.de
- update to 4.4.2
  o Fix applications sometimes starting on the wrong screen in
    multihead setups
  o Fix possible buffer overflow
  o Remove trailing parens on AC_INIT version info to work around
    bug in intltool 0.35.x and 0.36.x.
  o Updated and new translations
* Mon Nov 12 2007 prusnak@suse.cz
- use %%find_lang macro
- do not package INSTALL file
* Sun Oct 21 2007 bwalle@suse.de
- replaced group 'System/GUI/Other' by 'System/GUI/XFCE'
* Tue Apr 10 2007 bwalle@suse.de
- update to 4.4.1
  o Fix invalid g_slice_free1() in XfceRc code.
  o Fix bug when deleting groups.
  o Do not use GMemChunk for XfceRc module as that leaks all of its
    memory starting with GLib 2.10.
* Mon Jan 29 2007 pnemec@suse.cz
- removed providing %%name from package #236139
* Wed Jan 24 2007 stbinner@suse.de
- fix build
* Sun Jan 21 2007 bwalle@suse.de
- upgraded to 4.4.0
* Sat Nov  4 2006 bwalle@suse.de
- updated to 4.3.99.2 (4.4 rc2)
* Mon Sep  4 2006 pnemec@suse.cz
- updated to new version 4.3.99.1
* Wed Aug 23 2006 pnemec@suse.cz
- added dbus-devel to build requires
* Tue Aug  1 2006 pnemec@suse.cz
- initial comment, version is 4.3.90.2
- package moved into BuildService
- no patch needed
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 pnemec@suse.cz
- updated to 4.2.3
* Fri Sep 23 2005 cthiel@suse.de
- added -fno-strict-aliasing to CFLAGS
* Wed Sep 14 2005 cthiel@suse.de
- specfile cleanup
* Mon Aug  1 2005 cthiel@suse.de
- fixed Requires
* Wed May 18 2005 cthiel@suse.de
- fixed filelist
* Wed May 18 2005 cthiel@suse.de
- update to 4.2.2
* Mon Apr 11 2005 cthiel@suse.de
- update to 4.2.1
* Wed May 12 2004 ltinkl@suse.cz
- initial version
